@@ -52,6 +52,8 @@ object DiplomacyTurnManager {
                     otherCiv().addNotification("One of our trades with [${civInfo.civName}] has been cut short",
                         DiplomacyAction(civInfo.civName, true),
                         NotificationCategory.Trade, NotificationIcon.Trade, civInfo.civName)
+                    // If you cut a trade short, we're not going to trust you with per-turn trades for a while
+                    otherCivDiplomacy().setFlag(DiplomacyFlags.ResourceTradesCutShort, civInfo.gameInfo.speed.dealDuration * 2)
                     civInfo.cache.updateCivResources()
                 }
             }
