@@ -1,62 +1,24 @@
 package com.unciv.logic.map.mapunit
 
-import com.unciv.logic.UncivShowableException
 import com.unciv.models.ruleset.RejectionReasonType
 import com.unciv.models.ruleset.unique.StateForConditionals
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.ui.components.extensions.toPercent
+import com.unciv.ui.screens.worldscreen.unit.actions.UnitActionsUpgrade
 import kotlin.math.pow
 
-class UnitUpgradeManager(val unit:MapUnit) {
-
-    /** Returns FULL upgrade path, without checking what we can or cannot build currently.
-     * Does not contain current baseunit, so will be empty if no upgrades. */
-    private fun getUpgradePath(): Iterable<BaseUnit> {
-        var currentUnit = unit.baseUnit
-        val upgradeList = linkedSetOf<BaseUnit>()
-        while (currentUnit.upgradesTo != null) {
-            val nextUpgrade = unit.civ.getEquivalentUnit(currentUnit.upgradesTo!!)
-            if (nextUpgrade in upgradeList)
-                throw(UncivShowableException("Circular or self-referencing upgrade path for ${currentUnit.name}"))
-            currentUnit = nextUpgrade
-            upgradeList.add(currentUnit)
-        }
-        return upgradeList
-    }
-
-    /** Get the base unit this map unit could upgrade to, respecting researched tech and nation uniques only.
-     *  Note that if the unit can't upgrade, the current BaseUnit is returned.
-     */
-    // Used from UnitAutomation, UI action, canUpgrade
-    fun getUnitToUpgradeTo(): BaseUnit {
-        val upgradePath = getUpgradePath()
-
-        fun isInvalidUpgradeDestination(baseUnit: BaseUnit): Boolean{
-            if (!unit.civ.tech.isResearched(baseUnit))
-                return true
-            if (baseUnit.getMatchingUniques(UniqueType.OnlyAvailableWhen, StateForConditionals.IgnoreConditionals).any {
-                        !it.conditionalsApply(StateForConditionals(unit.civ, unit = unit ))
-                    }) return true
-            return false
-        }
-
-        for (baseUnit in upgradePath.reversed()) {
-            if (isInvalidUpgradeDestination(baseUnit)) continue
-            return baseUnit
-        }
-        return unit.baseUnit
-    }
+class UnitUpgradeManager(val unit: MapUnit) {
 
     /** Check whether this unit can upgrade to [unitToUpgradeTo]. This does not check or follow the
-     *  normal upgrade chain defined by [BaseUnit.upgradesTo], unless [unitToUpgradeTo] is left at default.
+     *  normal upgrade chain defined by [BaseUnit.getUpgradeUnits]
      *  @param ignoreRequirements Ignore possible tech/policy/building requirements (e.g. resource requirements still count).
      *          Used for upgrading units via ancient ruins.
      *  @param ignoreResources Ignore resource requirements (tech still counts)
      *          Used to display disabled Upgrade button
      */
     fun canUpgrade(
-        unitToUpgradeTo: BaseUnit = getUnitToUpgradeTo(),
+        unitToUpgradeTo: BaseUnit,
         ignoreRequirements: Boolean = false,
         ignoreResources: Boolean = false
     ): Boolean {
@@ -64,7 +26,9 @@ class UnitUpgradeManager(val unit:MapUnit) {
 
         val rejectionReasons = unitToUpgradeTo.getRejectionReasons(unit.civ, additionalResources = unit.getResourceRequirementsPerTurn())
 
-        var relevantRejectionReasons = rejectionReasons.filterNot { it.type == RejectionReasonType.Unbuildable }
+        var relevantRejectionReasons = rejectionReasons.filterNot {
+            it.isConstructionRejection() || it.type == RejectionReasonType.Obsoleted
+        }
         if (ignoreRequirements)
             relevantRejectionReasons = relevantRejectionReasons.filterNot { it.techPolicyEraWonderRequirements() }
         if (ignoreResources)
@@ -96,26 +60,50 @@ class UnitUpgradeManager(val unit:MapUnit) {
         for (unique in unit.civ.getMatchingUniques(UniqueType.UnitUpgradeCost, stateForConditionals))
             civModifier *= unique.params[0].toPercent()
 
-        val upgradePath = getUpgradePath()
-        var currentUnit = unit.baseUnit
-        for (baseUnit in upgradePath) {
-            // do clamping and rounding here so upgrading stepwise costs the same as upgrading far down the chain
-            var stepCost = constants.base
-            stepCost += (constants.perProduction * (baseUnit.cost - currentUnit.cost)).coerceAtLeast(0f)
-            val era = baseUnit.era(ruleset)
-            if (era != null)
-                stepCost *= (1f + era.eraNumber * constants.eraMultiplier)
-            stepCost = (stepCost * civModifier).pow(constants.exponent)
-            stepCost *= unit.civ.gameInfo.speed.modifier
-            goldCostOfUpgrade += (stepCost / constants.roundTo).toInt() * constants.roundTo
-            if (baseUnit == unitToUpgradeTo)
-                break  // stop at requested BaseUnit to upgrade to
-            currentUnit = baseUnit
-        }
-
+        var cost = constants.base
+        cost += (constants.perProduction * (unitToUpgradeTo.cost - unit.baseUnit.cost)).coerceAtLeast(0f)
+        val era = unitToUpgradeTo.era(ruleset)
+        if (era != null)
+            cost *= (1f + era.eraNumber * constants.eraMultiplier)
+        cost = (cost * civModifier).pow(constants.exponent)
+        cost *= unit.civ.gameInfo.speed.modifier
+        goldCostOfUpgrade += (cost / constants.roundTo).toInt() * constants.roundTo
 
         return goldCostOfUpgrade
     }
 
+    /** _Perform_ an upgrade, assuming validity checks were already passed.
+     *
+     *  Continuing to use a reference to this manager or its unit after this call is invalid!
+     *
+     *  Please use [UnitActionsUpgrade.getUpgradeActions] instead if at all possible.
+     *
+     *  Note - the upgraded unit is a new instance, and it's possible this method will need to place it on a different tile.
+     *  It is also possible the placement fails and the original is resurrected - in which case it is a **new instance** as well.
+     *  It might be desirable to return `newUnit` (or `resurrectedUnit`) if needed -
+     *  but then the lambda in UnitActionsUpgrade will complain and need to be forced back to Unit type.
+     */
+    fun performUpgrade(upgradedUnit: BaseUnit, isFree: Boolean, goldCostOfUpgrade: Int? = null) {
+        unit.destroy(destroyTransportedUnit = false)
+        val civ = unit.civ
+        val position = unit.currentTile.position
+        val newUnit = civ.units.placeUnitNearTile(position, upgradedUnit)
 
+        /** We were UNABLE to place the new unit, which means that the unit failed to upgrade!
+         * The only known cause of this currently is "land units upgrading to water units" which fail to be placed.
+         */
+        if (newUnit == null) {
+            val resurrectedUnit = civ.units.placeUnitNearTile(position, unit.baseUnit)!!
+            unit.copyStatisticsTo(resurrectedUnit)
+            return
+        }
+
+        // Managed to upgrade
+        if (!isFree) civ.addGold(-(goldCostOfUpgrade ?: getCostOfUpgrade(upgradedUnit)))
+        unit.copyStatisticsTo(newUnit)
+        newUnit.currentMovement = 0f
+        // wake up if lost ability to fortify
+        if (newUnit.isFortified() && !newUnit.canFortify(ignoreAlreadyFortified = true))
+            newUnit.action = null
+    }
 }
