@@ -96,8 +96,6 @@ class GameSettings {
 
     var autoPlay = GameSettingsAutoPlay()
 
-    var enableEspionageOption = false
-
     // This is a string not an enum so if tabs change it won't screw up the json serialization
     var lastOverviewPage = EmpireOverviewCategories.Cities.name
 
@@ -130,6 +128,11 @@ class GameSettings {
     /** Size of automatic display of UnitSet art in Civilopedia - 0 to disable */
     var pediaUnitArtSize = 0f
 
+    /** Don't close developer console after a successful command */
+    var keepConsoleOpen = false
+    /** Persist the history of successful developer console commands */
+    val consoleCommandHistory = ArrayList<String>()
+
     /** used to migrate from older versions of the settings */
     var version: Int? = null
 
@@ -251,7 +254,17 @@ class GameSettings {
 
     enum class NationPickerListMode { Icons, List }
 
+    /** Map Unciv language key to Java locale, for the purpose of getting a Collator for sorting.
+     *  - Effect depends on the Java libraries and may not always conform to expectations.
+     *    If in doubt, debug and see what Locale instance you get and compare its properties with `Locale.getDefault()`.
+     *    (`Collator.getInstance(LocaleCode.*.run { Locale(language, country) }) to Collator.getInstance())`, drill to both `rules`, compare hashes - if equal and other properties equal, then Java doesn't know your Language))
+     *  @property name same as translation file name with ' ', '_', '-', '(', ')' removed
+     *  @property language ISO 639-1 code for the language
+     *  @property country ISO 3166 code for the nation this is predominantly spoken in
+     *  @property trueLanguage If set, used instead of language to trick Java into supplying a close-enough collator (a no-match would otherwise give us the default collator, not a collator for a partial match)
+     */
     enum class LocaleCode(val language: String, val country: String, val trueLanguage: String? = null) {
+        Afrikaans("af", "ZA"),
         Arabic("ar", "IQ"),
         Belarusian("be", "BY"),
         Bosnian("bs", "BA"),
@@ -297,7 +310,7 @@ class GameSettings {
         Turkish("tr", "TR"),
         Ukrainian("uk", "UA"),
         Vietnamese("vi", "VN"),
-        Afrikaans("af", "ZA")
+        Zulu("zu", "ZA")
     }
 
     //endregion
