@@ -1,15 +1,18 @@
 package com.unciv.models.ruleset.nation
 
 import com.unciv.Constants
+import com.unciv.logic.civilization.Civilization
 import com.unciv.models.ruleset.RulesetObject
 import com.unciv.models.ruleset.unique.UniqueTarget
 import com.unciv.models.stats.Stat
+import com.unciv.models.stats.Stats
 import kotlin.reflect.KMutableProperty0
 
 /**
  * Type of Personality focus. Typically ranges from 0 (no focus) to 10 (double focus)
  */
 enum class PersonalityValue {
+    // Stat focused personalities
     Production,
     Food,
     Gold,
@@ -17,8 +20,13 @@ enum class PersonalityValue {
     Culture,
     Happiness,
     Faith,
-    Military,
-    WarMongering,;
+    // Behaviour focused personalities
+    Military, // Building a military but not nessesarily using it
+    Aggressive, // Declaring war determines expanding or defending
+    Commerce, // Trading frequency, open borders and liberating city-states, less negative diplomacy impact
+    Diplomacy, // Likelyhood of signing friendship, defensive pact, peace treaty and other diplomatic actions
+    Loyal, // Likelyhood to make a long lasting aliance with another civ and join wars with them
+    Expansion; // Founding/capturing new cities, oposite of a cultural victory
 
     companion object  {
         operator fun get(stat: Stat): PersonalityValue {
@@ -43,8 +51,14 @@ class Personality: RulesetObject() {
     var culture: Float = 5f
     var happiness: Float = 5f
     var faith: Float = 5f
+
     var military: Float = 5f
-    var warMongering: Float = 5f // Todo: Look into where this should be inserted
+    var aggressive: Float = 5f
+    var commerce: Float = 5f
+    var diplomacy: Float = 5f
+    var loyal: Float = 5f
+    var expansion: Float = 5f
+
     var priorities = LinkedHashMap<String, Int>()
     var preferredVictoryType: String = Constants.neutralVictoryType
     var isNeutralPersonality: Boolean = false
@@ -59,7 +73,11 @@ class Personality: RulesetObject() {
             PersonalityValue.Happiness -> ::happiness
             PersonalityValue.Faith -> ::faith
             PersonalityValue.Military -> ::military
-            PersonalityValue.WarMongering -> ::warMongering
+            PersonalityValue.Aggressive -> ::aggressive
+            PersonalityValue.Commerce -> ::commerce
+            PersonalityValue.Diplomacy -> ::diplomacy
+            PersonalityValue.Loyal -> ::loyal
+            PersonalityValue.Expansion -> ::expansion
         }
     }
 
@@ -78,6 +96,23 @@ class Personality: RulesetObject() {
         return nameToVariable(value).get() / 5
     }
 
+    /**
+     * @param weight a value between 0 and 1 that determines how much the modifier deviates from 1
+     * @return a modifier between 0 and 2 centered around 1 based off of the personality value and the weight given 
+     */
+    fun modifierFocus(value: PersonalityValue, weight: Float): Float {
+        return 1f + (scaledFocus(value) - 1) * weight
+    }
+
+    /**
+     * Scales the stats based on the personality and the weight given
+     * @param weight a positive value that determines how much the personality should impact the stats given 
+     */
+    fun scaleStats(stats: Stats, weight: Float): Stats {
+        Stat.values().forEach { stats[it] *= modifierFocus(PersonalityValue[it], weight) }
+        return stats
+    }
+
     operator fun get(value: PersonalityValue): Float {
         return nameToVariable(value).get()
     }
