@@ -3,81 +3,100 @@ package com.unciv.ui.screens.devconsole
 import com.badlogic.gdx.Input
 import com.badlogic.gdx.graphics.Color
 import com.badlogic.gdx.scenes.scene2d.actions.Actions
-import com.badlogic.gdx.scenes.scene2d.ui.TextField
+import com.unciv.Constants
 import com.unciv.logic.map.mapunit.MapUnit
+import com.unciv.ui.components.UncivTextField
+import com.unciv.ui.components.extensions.toCheckBox
 import com.unciv.ui.components.extensions.toLabel
 import com.unciv.ui.components.input.KeyCharAndCode
 import com.unciv.ui.components.input.keyShortcuts
 import com.unciv.ui.popups.Popup
-import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.screens.worldscreen.WorldScreen
 
 
 class DevConsolePopup(val screen: WorldScreen) : Popup(screen) {
     companion object {
-        val history = ArrayList<String>()
+        private const val maxHistorySize = 42
     }
+    private val history by screen.game.settings::consoleCommandHistory
+    private var keepOpen by screen.game.settings::keepConsoleOpen
+
     private var currentHistoryEntry = history.size
 
-    private val textField = TextField("", BaseScreen.skin)
+    private val textField = UncivTextField.create("", "") // always has focus, so a hint won't show
     private val responseLabel = "".toLabel(Color.RED).apply { wrap = true }
 
     private val commandRoot = ConsoleCommandRoot()
     internal val gameInfo = screen.gameInfo
 
     init {
-        add(textField).width(stageToShowOn.width / 2).row()
+        // Use untranslated text here! The entire console, including messages, should stay English.
+        // But "Developer Console" *has* a translation from KeyboardBinding.DeveloperConsole.
+        // The extensions still help, even with a "don't translate" kludge ("Keep open" has no template but might in the future).
+        add("Developer Console {}".toLabel(fontSize = Constants.headingFontSize)).growX()  // translation template is automatic via the keybinding
+        add("Keep open {}".toCheckBox(keepOpen) { keepOpen = it }).right().row()
+
+        add(textField).width(stageToShowOn.width / 2).colspan(2).row()
         textField.keyShortcuts.add(Input.Keys.ENTER, ::onEnter)
 
-        // Without this, console popup will always contain a `
+        // Without this, console popup will always contain the key used to open it - won't work perfectly if it's configured to a "dead key"
         textField.addAction(Actions.delay(0.05f, Actions.run { textField.text = "" }))
 
-        add(responseLabel).maxWidth(screen.stage.width * 0.8f)
-
-        open(true)
+        add(responseLabel).colspan(2).maxWidth(screen.stage.width * 0.8f)
 
         keyShortcuts.add(KeyCharAndCode.BACK) { close() }
+        clickBehindToClose = true
 
-        keyShortcuts.add(KeyCharAndCode.TAB) {
+        textField.keyShortcuts.add(KeyCharAndCode.TAB) {
             val textToAdd = getAutocomplete()
             textField.appendText(textToAdd)
         }
 
-        if (history.isNotEmpty()) {
-            keyShortcuts.add(Input.Keys.UP) {
-                if (currentHistoryEntry > 0) currentHistoryEntry--
-                textField.text = history[currentHistoryEntry]
-                textField.cursorPosition = textField.text.length
-            }
-            keyShortcuts.add(Input.Keys.DOWN) {
-                if (currentHistoryEntry == history.size) currentHistoryEntry--
-                if (currentHistoryEntry < history.lastIndex) currentHistoryEntry++
-                textField.text = history[currentHistoryEntry]
-                textField.cursorPosition = textField.text.length
-            }
-        }
+        keyShortcuts.add(Input.Keys.UP) { navigateHistory(-1) }
+        keyShortcuts.add(Input.Keys.DOWN) { navigateHistory(1) }
+
+        open(true)
 
         screen.stage.keyboardFocus = textField
     }
 
+    private fun navigateHistory(delta: Int) {
+        if (history.isEmpty()) return
+        currentHistoryEntry = (currentHistoryEntry + delta).coerceIn(history.indices)
+        textField.text = history[currentHistoryEntry]
+        textField.cursorPosition = textField.text.length
+    }
+
     private fun onEnter() {
         val handleCommandResponse = handleCommand()
         if (handleCommandResponse.isOK) {
             screen.shouldUpdate = true
-            if (history.isEmpty() || history.last() != textField.text)
-                history.add(textField.text)
-            close()
+            addHistory()
+            if (!keepOpen) close() else textField.text = ""
             return
         }
         showResponse(handleCommandResponse.message, handleCommandResponse.color)
     }
 
+    private fun addHistory() {
+        val text = textField.text
+        if (text.isBlank()) return
+        if (history.isNotEmpty() && history.last().equals(text, true)) return
+        if (history.size >= maxHistorySize) {
+            history.removeAll { it.equals(text, true) }
+            if (history.size >= maxHistorySize)
+                history.removeAt(0)
+        }
+        history.add(textField.text)
+        currentHistoryEntry = history.size
+    }
+
     internal fun showResponse(message: String?, color: Color) {
         responseLabel.setText(message)
         responseLabel.style.fontColor = color
     }
 
-    val splitStringRegex = Regex("\"([^\"]+)\"|\\S+") // Read: "(phrase)" OR non-whitespace
+    private val splitStringRegex = Regex("\"([^\"]+)\"|\\S+") // Read: "(phrase)" OR non-whitespace
     private fun getParams(text: String): List<String> {
         return splitStringRegex.findAll(text).map { it.value.removeSurrounding("\"") }.filter { it.isNotEmpty() }.toList()
     }
